@@ -1,20 +1,23 @@
 from roseta.transform.transform import transform
-from roseta.transform.height import trans_height
+from roseta.transform.no_class import trans_no_class
+from roseta.transform.length import trans_length
 from roseta.transform.weight import trans_weight
 from roseta.transform.city import trans_city
-from roseta.transform.foot import trans_foot
-from roseta.transform.no_class import trans_no_class
+from roseta.transform.age import trans_age
+from roseta.transform.cup import trans_cup
+
 
 trans = transform
 
-__version__ = "0.1.3"
+__version__ = "0.1.7"
 
 __all__ = [
     "trans",
     "transform",
-    "trans_height",
+    "trans_no_class",
+    "trans_length",
     "trans_weight",
     "trans_city",
-    "trans_foot",
-    "trans_no_class",
+    "trans_age",
+    "trans_cup"
 ]
